PgBox

Struct PgBox 

pub struct PgBox {
    pub upper_right_x: f64,
    pub upper_right_y: f64,
    pub lower_left_x: f64,
    pub lower_left_y: f64,
}
Postgres Geometric Box type

Description: Rectangular box Representation: ((upper_right_x,upper_right_y),(lower_left_x,lower_left_y))

Boxes are represented by pairs of points that are opposite corners of the box. Values of type box are specified using any of the following syntaxes:

( ( upper_right_x , upper_right_y ) , ( lower_left_x , lower_left_y ) )
( upper_right_x , upper_right_y ) , ( lower_left_x , lower_left_y )
  upper_right_x , upper_right_y   ,   lower_left_x , lower_left_y

where (upper_right_x,upper_right_y) and (lower_left_x,lower_left_y) are any two opposite corners of the box. Any two opposite corners can be supplied on input, but the values will be reordered as needed to store the upper right and lower left corners, in that order.

See Postgres Manual, Section 8.8.4: Geometric Types - Boxes for details.

Fields

upper_right_x: f64upper_right_y: f64lower_left_x: f64lower_left_y: f64