PgLQueryVariantFlag

Struct PgLQueryVariantFlag 

pub struct PgLQueryVariantFlag(/* private fields */);
Modifiers that can be set to non-star labels

Implementations



impl PgLQueryVariantFlag

pub const ANY_END: PgLQueryVariantFlag

    • Match any label with this prefix, for example foo* matches foobar

pub const IN_CASE: PgLQueryVariantFlag

@ - Match case-insensitively, for example a@ matches A

pub const SUBLEXEME: PgLQueryVariantFlag

% - Match initial underscore-separated words



impl PgLQueryVariantFlag

pub const fn empty() -> PgLQueryVariantFlag

Get a flags value with all bits unset.

pub const fn all() -> PgLQueryVariantFlag

Get a flags value with all known bits set.

pub const fn bits(&self) -> u16

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u16) -> Option<PgLQueryVariantFlag>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u16) -> PgLQueryVariantFlag

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u16) -> PgLQueryVariantFlag

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<PgLQueryVariantFlag>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in self are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: PgLQueryVariantFlag) -> bool

Whether any set bits in other are also set in self.

pub const fn contains(&self, other: PgLQueryVariantFlag) -> bool

Whether all set bits in other are also set in self.

pub fn insert(&mut self, other: PgLQueryVariantFlag)

The bitwise or (|) of the bits in self and other.

pub fn remove(&mut self, other: PgLQueryVariantFlag)

The intersection of self with the complement of other (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: PgLQueryVariantFlag)

The bitwise exclusive-or (^) of the bits in self and other.

pub fn set(&mut self, other: PgLQueryVariantFlag, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection( self, other: PgLQueryVariantFlag, ) -> PgLQueryVariantFlag

The bitwise and (&) of the bits in self and other.

pub const fn union(self, other: PgLQueryVariantFlag) -> PgLQueryVariantFlag

The bitwise or (|) of the bits in self and other.

pub const fn difference(self, other: PgLQueryVariantFlag) -> PgLQueryVariantFlag

The intersection of self with the complement of other (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference( self, other: PgLQueryVariantFlag, ) -> PgLQueryVariantFlag

The bitwise exclusive-or (^) of the bits in self and other.

pub const fn complement(self) -> PgLQueryVariantFlag

The bitwise negation (!) of the bits in self, truncating the result.



impl PgLQueryVariantFlag

pub const fn iter(&self) -> Iter<PgLQueryVariantFlag>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<PgLQueryVariantFlag>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.