Struct PgLSeg
pub struct PgLSeg {
pub start_x: f64,
pub start_y: f64,
pub end_x: f64,
pub end_y: f64,
}Expand description
Postgres Geometric Line Segment type
Description: Finite line segment
Representation: ((start_x,start_y),(end_x,end_y))
Line segments are represented by pairs of points that are the endpoints of the segment. Values of type lseg are specified using any of the following syntaxes:
[ ( start_x , start_y ) , ( end_x , end_y ) ]
( ( start_x , start_y ) , ( end_x , end_y ) )
( start_x , start_y ) , ( end_x , end_y )
start_x , start_y , end_x , end_ywhere (start_x,start_y) and (end_x,end_y) are the end points of the line segment.
See Postgres Manual, Section 8.8.3, Geometric Types - Line Segments for details.
Fields
start_x: f64start_y: f64end_x: f64end_y: f64Trait Implementations
impl<'q> Encode<'q, Postgres> for PgLSeg
impl<'q> Encode<'q, Postgres> for PgLSeg
fn produces(&self) -> Option<PgTypeInfo>
fn encode_by_ref(
&self,
buf: &mut PgArgumentBuffer,
) -> Result<IsNull, Box<dyn Error + Sync + Send>>
fn encode_by_ref( &self, buf: &mut PgArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>
fn encode(
self,
buf: &mut <DB as Database>::ArgumentBuffer<'q>,
) -> Result<IsNull, Box<dyn Error + Sync + Send>>where
Self: Sized,
fn encode(
self,
buf: &mut <DB as Database>::ArgumentBuffer<'q>,
) -> Result<IsNull, Box<dyn Error + Sync + Send>>where
Self: Sized,
self into buf in the expected format for the database.fn size_hint(&self) -> usize
impl PgHasArrayType for PgLSeg
impl PgHasArrayType for PgLSeg
fn array_type_info() -> PgTypeInfo
fn array_compatible(ty: &PgTypeInfo) -> bool
impl Type<Postgres> for PgLSeg
impl Type<Postgres> for PgLSeg
fn type_info() -> PgTypeInfo
fn type_info() -> PgTypeInfo
impl StructuralPartialEq for PgLSeg