Struct PgLine
pub struct PgLine {
pub a: f64,
pub b: f64,
pub c: f64,
}Expand description
Postgres Geometric Line type
Description: Infinite line
Representation: {A, B, C}
Lines are represented by the linear equation Ax + By + C = 0, where A and B are not both zero.
See Postgres Manual, Section 8.8.2, Geometric Types - Lines for details.
Fields
a: f64b: f64c: f64Trait Implementations
impl<'q> Encode<'q, Postgres> for PgLine
impl<'q> Encode<'q, Postgres> for PgLine
fn produces(&self) -> Option<PgTypeInfo>
fn encode_by_ref(
&self,
buf: &mut PgArgumentBuffer,
) -> Result<IsNull, Box<dyn Error + Sync + Send>>
fn encode_by_ref( &self, buf: &mut PgArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>
fn encode(
self,
buf: &mut <DB as Database>::ArgumentBuffer<'q>,
) -> Result<IsNull, Box<dyn Error + Sync + Send>>where
Self: Sized,
fn encode(
self,
buf: &mut <DB as Database>::ArgumentBuffer<'q>,
) -> Result<IsNull, Box<dyn Error + Sync + Send>>where
Self: Sized,
self into buf in the expected format for the database.fn size_hint(&self) -> usize
impl PgHasArrayType for PgLine
impl PgHasArrayType for PgLine
fn array_type_info() -> PgTypeInfo
fn array_compatible(ty: &PgTypeInfo) -> bool
impl Type<Postgres> for PgLine
impl Type<Postgres> for PgLine
fn type_info() -> PgTypeInfo
fn type_info() -> PgTypeInfo
impl StructuralPartialEq for PgLine