Struct PgPoint
pub struct PgPoint {
pub x: f64,
pub y: f64,
}Expand description
Postgres Geometric Point type
Description: Point on a plane
Representation: (x, y)
Points are the fundamental two-dimensional building block for geometric types. Values of type point are specified using either of the following syntaxes:
( x , y )
x , ywhere x and y are the respective coordinates, as floating-point numbers.
See Postgres Manual, Section 8.8.1, Geometric Types - Points for details.
Fields
x: f64y: f64Trait Implementations
impl<'q> Encode<'q, Postgres> for PgPoint
impl<'q> Encode<'q, Postgres> for PgPoint
fn produces(&self) -> Option<PgTypeInfo>
fn encode_by_ref(
&self,
buf: &mut PgArgumentBuffer,
) -> Result<IsNull, Box<dyn Error + Sync + Send>>
fn encode_by_ref( &self, buf: &mut PgArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>
fn encode(
self,
buf: &mut <DB as Database>::ArgumentBuffer<'q>,
) -> Result<IsNull, Box<dyn Error + Sync + Send>>where
Self: Sized,
fn encode(
self,
buf: &mut <DB as Database>::ArgumentBuffer<'q>,
) -> Result<IsNull, Box<dyn Error + Sync + Send>>where
Self: Sized,
self into buf in the expected format for the database.fn size_hint(&self) -> usize
impl PgHasArrayType for PgPoint
impl PgHasArrayType for PgPoint
fn array_type_info() -> PgTypeInfo
fn array_compatible(ty: &PgTypeInfo) -> bool
impl Type<Postgres> for PgPoint
impl Type<Postgres> for PgPoint
fn type_info() -> PgTypeInfo
fn type_info() -> PgTypeInfo
impl StructuralPartialEq for PgPoint