Struct PgTimeTz
pub struct PgTimeTz<Time = NaiveTime, Offset = FixedOffset> {
pub time: Time,
pub offset: Offset,
}Expand description
Represents a moment of time, in a specified timezone.
Warning
PgTimeTz provides TIMETZ and is supported only for reading from legacy databases.
PostgreSQL recommends to use TIMESTAMPTZ instead.
Fields
time: Timeoffset: OffsetTrait Implementations
impl Encode<'_, Postgres> for PgTimeTz
impl Encode<'_, Postgres> for PgTimeTz
fn encode_by_ref(
&self,
buf: &mut PgArgumentBuffer,
) -> Result<IsNull, Box<dyn Error + Sync + Send>>
fn encode_by_ref( &self, buf: &mut PgArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>
fn size_hint(&self) -> usize
fn encode(
self,
buf: &mut <DB as Database>::ArgumentBuffer<'q>,
) -> Result<IsNull, Box<dyn Error + Sync + Send>>where
Self: Sized,
fn encode(
self,
buf: &mut <DB as Database>::ArgumentBuffer<'q>,
) -> Result<IsNull, Box<dyn Error + Sync + Send>>where
Self: Sized,
self into buf in the expected format for the database.fn produces(&self) -> Option<<DB as Database>::TypeInfo>
impl<Time, Offset> PgHasArrayType for PgTimeTz<Time, Offset>
impl<Time, Offset> PgHasArrayType for PgTimeTz<Time, Offset>
fn array_type_info() -> PgTypeInfo
fn array_compatible(ty: &PgTypeInfo) -> bool
impl Type<Postgres> for PgTimeTz
impl Type<Postgres> for PgTimeTz
fn type_info() -> PgTypeInfo
fn type_info() -> PgTypeInfo
impl<Time, Offset> Copy for PgTimeTz<Time, Offset>
impl<Time, Offset> StructuralPartialEq for PgTimeTz<Time, Offset>