Struct PgBox
pub struct PgBox {
pub upper_right_x: f64,
pub upper_right_y: f64,
pub lower_left_x: f64,
pub lower_left_y: f64,
}Expand description
Postgres Geometric Box type
Description: Rectangular box
Representation: ((upper_right_x,upper_right_y),(lower_left_x,lower_left_y))
Boxes are represented by pairs of points that are opposite corners of the box. Values of type box are specified using any of the following syntaxes:
( ( upper_right_x , upper_right_y ) , ( lower_left_x , lower_left_y ) )
( upper_right_x , upper_right_y ) , ( lower_left_x , lower_left_y )
upper_right_x , upper_right_y , lower_left_x , lower_left_ywhere (upper_right_x,upper_right_y) and (lower_left_x,lower_left_y) are any two opposite corners of the box.
Any two opposite corners can be supplied on input, but the values will be reordered as needed to store the upper right and lower left corners, in that order.
See Postgres Manual, Section 8.8.4: Geometric Types - Boxes for details.
Fields
upper_right_x: f64upper_right_y: f64lower_left_x: f64lower_left_y: f64Trait Implementations
impl<'q> Encode<'q, Postgres> for PgBox
impl<'q> Encode<'q, Postgres> for PgBox
fn produces(&self) -> Option<PgTypeInfo>
fn encode_by_ref(
&self,
buf: &mut PgArgumentBuffer,
) -> Result<IsNull, Box<dyn Error + Sync + Send>>
fn encode_by_ref( &self, buf: &mut PgArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>
fn encode(
self,
buf: &mut <DB as Database>::ArgumentBuffer<'q>,
) -> Result<IsNull, Box<dyn Error + Sync + Send>>where
Self: Sized,
fn encode(
self,
buf: &mut <DB as Database>::ArgumentBuffer<'q>,
) -> Result<IsNull, Box<dyn Error + Sync + Send>>where
Self: Sized,
self into buf in the expected format for the database.fn size_hint(&self) -> usize
impl PgHasArrayType for PgBox
impl PgHasArrayType for PgBox
fn array_type_info() -> PgTypeInfo
fn array_compatible(ty: &PgTypeInfo) -> bool
impl Type<Postgres> for PgBox
impl Type<Postgres> for PgBox
fn type_info() -> PgTypeInfo
fn type_info() -> PgTypeInfo
impl StructuralPartialEq for PgBox