Struct PgPath
pub struct PgPath {
pub closed: bool,
pub points: Vec<PgPoint>,
}Expand description
Postgres Geometric Path type
Description: Open path or Closed path (similar to polygon)
Representation: Open [(x1,y1),...], Closed ((x1,y1),...)
Paths are represented by lists of connected points. Paths can be open, where the first and last points in the list are considered not connected, or closed, where the first and last points are considered connected. Values of type path are specified using any of the following syntaxes:
[ ( x1 , y1 ) , ... , ( xn , yn ) ]
( ( x1 , y1 ) , ... , ( xn , yn ) )
( x1 , y1 ) , ... , ( xn , yn )
( x1 , y1 , ... , xn , yn )
x1 , y1 , ... , xn , ynwhere the points are the end points of the line segments comprising the path. Square brackets ([]) indicate an open path, while parentheses (()) indicate a closed path.
When the outermost parentheses are omitted, as in the third through fifth syntaxes, a closed path is assumed.
See Postgres Manual, Section 8.8.5, Geometric Types - Paths for details.
Fields
closed: boolpoints: Vec<PgPoint>Trait Implementations
impl<'q> Encode<'q, Postgres> for PgPath
impl<'q> Encode<'q, Postgres> for PgPath
fn produces(&self) -> Option<PgTypeInfo>
fn encode_by_ref(
&self,
buf: &mut PgArgumentBuffer,
) -> Result<IsNull, Box<dyn Error + Sync + Send>>
fn encode_by_ref( &self, buf: &mut PgArgumentBuffer, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>
fn encode(
self,
buf: &mut <DB as Database>::ArgumentBuffer<'q>,
) -> Result<IsNull, Box<dyn Error + Sync + Send>>where
Self: Sized,
fn encode(
self,
buf: &mut <DB as Database>::ArgumentBuffer<'q>,
) -> Result<IsNull, Box<dyn Error + Sync + Send>>where
Self: Sized,
self into buf in the expected format for the database.fn size_hint(&self) -> usize
impl PgHasArrayType for PgPath
impl PgHasArrayType for PgPath
fn array_type_info() -> PgTypeInfo
fn array_compatible(ty: &PgTypeInfo) -> bool
impl Type<Postgres> for PgPath
impl Type<Postgres> for PgPath
fn type_info() -> PgTypeInfo
fn type_info() -> PgTypeInfo
impl StructuralPartialEq for PgPath